@@ -37,6 +37,7 @@ filter 'JSON::Typist::Number' => sub {
 foreach my $json (qw(
     JSON::DWIW::Boolean   JSON::PP::Boolean   JSON::SL::Boolean
     JSON::XS::Boolean     boolean             JSON::Tiny::_Bool
+    Mojo::JSON::_Bool
 )) {
     filter "$json" => sub {
         my ($obj, $ddp) = @_;
@@ -141,8 +142,7 @@ filter 'HTTP::Request' => sub {
         $output .= ' {';
         $ddp->indent;
         if ($expand_headers) {
-            my $header_obj = $obj->headers;
-            if ($header_obj->can('flatten')) {
+            if ($obj->headers->can('flatten')) {
                 my %headers = $obj->headers->flatten;
                 $output .= $ddp->newline . 'headers: ' . $ddp->parse(\%headers);
             }
@@ -197,8 +197,10 @@ filter 'HTTP::Response' => sub {
         $output .= ' {';
         $ddp->indent;
         if ($expand_headers) {
-            my %headers = $obj->headers->flatten;
-            $output .= $ddp->newline . 'headers: ' . $ddp->parse(\%headers);
+            if ($obj->headers->can('flatten')) {
+                my %headers = $obj->headers->flatten;
+                $output .= $ddp->newline . 'headers: ' . $ddp->parse(\%headers);
+            }
         }
         if ($content) {
             $output .= $ddp->newline . 'content: '
